@@ -32,7 +32,6 @@
 
 typedef struct GnomeVFSJob GnomeVFSJob;
 
-
 #define GNOME_VFS_JOB_DEBUG 0
 
 #if GNOME_VFS_JOB_DEBUG
@@ -79,7 +78,11 @@ enum GnomeVFSOpType {
 	GNOME_VFS_OP_FIND_DIRECTORY,
 	GNOME_VFS_OP_XFER,
 	GNOME_VFS_OP_GET_FILE_INFO,
-	GNOME_VFS_OP_SET_FILE_INFO
+	GNOME_VFS_OP_SET_FILE_INFO,
+	/* This is not a real OpType; its intended to mark
+	 * GnomeVFSAsyncModuleCallback's in the job_callback queue
+	 */
+	GNOME_VFS_OP_MODULE_CALLBACK
 };
 
 typedef enum GnomeVFSOpType GnomeVFSOpType;
@@ -141,6 +144,7 @@ typedef struct {
 } GnomeVFSCreateAsChannelOpResult;
 
 typedef struct {
+	char dummy; /* ANSI C does not allow empty structs */
 } GnomeVFSCloseOp;
 
 typedef struct {
@@ -251,6 +255,17 @@ typedef struct {
 	int reply;
 } GnomeVFSXferOpResult;
 
+typedef struct {
+	GnomeVFSAsyncModuleCallback    callback;
+	gpointer                       user_data;
+	gconstpointer		       in;
+	size_t			       in_size;
+	gpointer                       out;
+	size_t			       out_size;
+	GnomeVFSModuleCallbackResponse response;
+	gpointer                       response_data;
+} GnomeVFSModuleCallbackOpResult;
+
 typedef union {
 	GnomeVFSOpenOp open;
 	GnomeVFSOpenAsChannelOp open_as_channel;
@@ -280,6 +295,7 @@ typedef struct {
 
 	/* The context for cancelling the operation. */
 	GnomeVFSContext *context;
+	GnomeVFSModuleCallbackStackInfo *stack_info;
 } GnomeVFSOp;
 
 typedef union {
@@ -295,6 +311,7 @@ typedef union {
 	GnomeVFSFindDirectoryOpResult find_directory;
 	GnomeVFSLoadDirectoryOpResult load_directory;
 	GnomeVFSXferOpResult xfer;
+	GnomeVFSModuleCallbackOpResult callback;
 } GnomeVFSSpecificNotifyResult;
 
 typedef struct {
@@ -360,5 +377,4 @@ int          	 gnome_vfs_job_get_count 	  (void);
 
 gboolean	 gnome_vfs_job_complete		  (GnomeVFSJob 		*job);
 
-
 #endif /* GNOME_VFS_JOB_PTHREAD_H */
