@@ -21,11 +21,13 @@
    Author: Michael Meeks <michael@imaginator.com>
 */
 
-#ifndef _GNOME_SEEKABLE_H
-#define _GNOME_SEEKABLE_H
+#ifndef GNOME_SEEKABLE_H
+#define GNOME_SEEKABLE_H
+
+#include <libgnomevfs/gnome-vfs-method.h>
 
 GnomeVFSMethodHandle *gnome_vfs_seek_emulate (GnomeVFSURI          *handle,
 					      GnomeVFSMethodHandle *child_handle,
 					      GnomeVFSOpenMode      open_mode);
 
-#endif /* _GNOME_VFS_OPS_H */
+#endif /* GNOME_VFS_SEEKABLE_H */
